==> peperit_2.1_estable.zip: themes/peperit/html_files/componentes/plantilla/aside_top.php <==
<?php
//---------------------------------------------------------------------------------------------------------
// 29/Julio/2020 (Pedro)
// Dividimos el Aside en dos partes para mostrar una antes y otra después del contenido en dispositivos móviles
$ultimosPost = true;
$id_capa_filtrado = Sections::getParam('id_capa_filtrado');
$filtradoProductos = Theme::getConfigParam('filterProducts', false);
$tieneBlog = Theme::getConfigParam('hasBlog', false);
$ultimosPost = Theme::getConfigParam('ultimosPosts', false);
$tieneBlog = Theme::getConfigParam('hasBlog', false);
$asideShowCategories = Theme::getConfigParam('asideShowCategories', false);
//Si no tiene blog, tampoco muestra los últimos posts:
if (!$tieneBlog) {
	$ultimosPost = false;
}

//Partes de este aside:
// 1.- Banners propios (condición "aside_top")
// 2.- Banners específicos (condición de escaparate o términos de búsqueda)
//  2.1 - Etiquetas de búsqueda
// 3.- Filtrados

?>
<div class="columna-banner col-xs-6 col-lg-12">
    <div class="banner_aside">
        <?php
        //$ruta_cabecera = Theme::include_file("banner_novedades.php");
        new Widget($_WH->GW('banner'), 'banner', 'aside_top', 1, true);
        ?>
    </div>
</div>
<?php
//Determinamos si estamos en un escaparate, búsqueda o ficha de producto:
$escaparate_actual = Sections::getParam('escaparate');
$busqueda_actual = Sections::getParam('busqueda_actual');
$articulo_actual = Sections::getParam('articulo');

if ($escaparate_actual != NULL){
    //Estamos en un escaparate, cogemos los banners de la consdición del mismo:
    if ($escaparate_actual->condicion != ''){
        ?>
        <div class="columna-banner col-xs-6 col-lg-12">
            <div class="banner_aside">
                <?php
                new Widget($_WH->GW('banner'), 'banner', $escaparate_actual->condicion, 1, true);
                //$ruta_cabecera = Theme::include_file("banner_novedades.php");
                ?>
            </div>
        </div>
        <?php
    }
}else if ($busqueda_actual != NULL){
    //Estamos en una búsqueda, vamos a insertar las etiquetas
    
}else if ($articulo_actual != NULL){
    //En el futuro podremos añadir aquí cosas relacionadas con el artículo:
}

if ($filtradoProductos){
?>
<div id="<?= $id_capa_filtrado; ?>" class="columna-filtrado col-xs-6 col-lg-12">
    <?php
    if(Sections::$current_section == 'escaparate'){
        $ruta_cabecera = Theme::include_file("filtrados_en_escaparate.php");

    }else if(Sections::$current_section == 'resultado_busqueda'){
        $ruta_cabecera = Theme::include_file("filtrados_en_busqueda.php");
    }
    ?>
</div>
<?php
}
?>

==> peperit_2.1.01_estable.zip: themes/peperit/html_files/componentes/plantilla/aside_top.php <==
<?php
//---------------------------------------------------------------------------------------------------------
// 29/Julio/2020 (Pedro)
// Dividimos el Aside en dos partes para mostrar una antes y otra después del contenido en dispositivos móviles
$ultimosPost = true;
$id_capa_filtrado = Sections::getParam('id_capa_filtrado');
$filtradoProductos = Theme::getConfigParam('filterProducts', false);
$tieneBlog = Theme::getConfigParam('hasBlog', false);
$ultimosPost = Theme::getConfigParam('ultimosPosts', false);
$tieneBlog = Theme::getConfigParam('hasBlog', false);
$asideShowCategories = Theme::getConfigParam('asideShowCategories', false);
//Si no tiene blog, tampoco muestra los últimos posts:
if (!$tieneBlog) {
	$ultimosPost = false;
}

//Partes de este aside:
// 1.- Banners propios (condición "aside_top")
// 2.- Banners específicos (condición de escaparate o términos de búsqueda)
//  2.1 - Etiquetas de búsqueda
// 3.- Filtrados

?>
<div class="columna-banner col-xs-6 col-lg-12">

        <?php
        //$ruta_cabecera = Theme::include_file("banner_novedades.php");
        new Widget($_WH->GW('banner'), 'banner_aside_top', 'aside_top', 1, true);
        ?>
</div>
<?php
//Determinamos si estamos en un escaparate, búsqueda o ficha de producto:
$escaparate_actual = Sections::getParam('escaparate');
$busqueda_actual = Sections::getParam('busqueda_actual');
$articulo_actual = Sections::getParam('articulo');

if ($escaparate_actual != NULL){
    //Estamos en un escaparate, cogemos los banners de la consdición del mismo:
    if ($escaparate_actual->condicion != ''){
        ?>
        <div class="columna-banner col-xs-6 col-lg-12">
                <?php
                new Widget($_WH->GW('banner'), 'banner_aside_top', $escaparate_actual->condicion, 1, true);
                //$ruta_cabecera = Theme::include_file("banner_novedades.php");
                ?>
        </div>
        <?php
    }
}else if ($busqueda_actual != NULL){
    //Estamos en una búsqueda, vamos a insertar las etiquetas
    
}else if ($articulo_actual != NULL){
    //En el futuro podremos añadir aquí cosas relacionadas con el artículo:
}

if ($filtradoProductos){
?>
<div id="<?= $id_capa_filtrado; ?>" class="columna-filtrado col-xs-6 col-lg-12">
    <?php
    if(Sections::$current_section == 'escaparate'){
        $ruta_cabecera = Theme::include_file("filtrados_en_escaparate.php");

    }else if(Sections::$current_section == 'resultado_busqueda'){
        $ruta_cabecera = Theme::include_file("filtrados_en_busqueda.php");
    }
    ?>
</div>
<?php
}
?>
